/*
 * Project name:
     Boot_Test (using mikroC Bootloader on PIC18's 96K ROM)
 * Copyright:
     (c) FOURNET Olivier 05/08/2017
 * Revision History:
     20051120:
       - initial release (for 64K ROM)
         20170805 :
           - adaptation du code initial de Mikroelektronika a une version PIC18F de 96K ROM
         
 * Description:
     This is a serial port Bootloader implementation exemple test. 
 * Test configuration:
     MCU:             PIC18F4685
                      http://ww1.microchip.com/downloads/en/DeviceDoc/39761c.pdf
     Oscillator:      HS, 12.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/mikroc/pic/
 * NOTES:
     - It's recommended not to alter the start address of the main().
       Otherwise, less space in ROM will be available for the application being bootloaded.
     - RX and TX UART switches should be turned On (board specific).
 */

//-------------- main for 96K PIC18's

//char uart_rd;
int adc0;
static float kVref=4.8828125e-3; // kVref = Vref(5V) / 1024
float an0;

char str[16];

void main() 
{
  /*ANSEL  = 0;                     // Configure AN pins as digital
  ANSELH = 0;  */
  //ANSEL  = 0x04;              // Configure AN2 pin as analog
  PORTA = 0 ;
  TRISA  = 0xFF;              // PORTA is input
  ADCON1 = 0x82;  // Vref+ = VDD, Vref- = VSS, RA0  RA5 = ADCin
  
  UART1_Init(9600);               // Initialize UART module at 9600 bps
  Delay_ms(1000);                  // Wait for UART module to stabilize
  
  UART1_Write_Text("\n\nStart using mikroC Bootloader on PIC18F4685 (96K ROM) v1.0.0.1\n\n");
  UART1_Write(10);
  UART1_Write(13);

  while(1) 
  {                     // Endless loop
  /*
    if (UART1_Data_Ready()) 
    {     // If data is received,
      uart_rd = UART1_Read();     // read the received data,
      UART1_Write(uart_rd);       // and send data via UART
    }
    */
    UART1_Write_Text("ADC0: ");
    adc0 = ADC_Read(0);   // Get 10-bit results of AD conversion
    IntToStr(adc0, str);
    UART1_Write_Text(str);
    UART1_Write_Text(" , ");
    an0  = (float)adc0 * kVref; // an0(V) = ADC*(Vref/1024)
    FloatToStr(an0, str);
    UART1_Write_Text(str);
    UART1_Write_Text("V ");

    UART1_Write(10);
    UART1_Write(13);
  }
}